@@ -1,5 +1,6 @@
 """Provide support to Lexicon for AWS Route 53 DNS changes."""
 from __future__ import absolute_import
+import hashlib
 import logging
 import re
 
@@ -135,7 +136,14 @@ class Provider(BaseProvider):
 
     def _change_record_sets(self, action, rtype, name, content):
         ttl = self._get_lexicon_option('ttl')
-        value = '"{0}"'.format(content) if rtype in ['TXT', 'SPF'] else content
+        resource_records = []
+        if isinstance(content, list):
+            for i in content:
+                value = '"{0}"'.format(i) if rtype in ['TXT', 'SPF'] else i
+                resource_records.append({'Value': value})
+        else:
+            value = '"{0}"'.format(content) if rtype in ['TXT', 'SPF'] else content
+            resource_records.append({'Value': value})
         try:
             self.r53_client.change_resource_record_sets(
                 HostedZoneId=self.domain_id,
@@ -150,11 +158,7 @@ class Provider(BaseProvider):
                                 'Name': self._fqdn_name(name),
                                 'Type': rtype,
                                 'TTL': ttl if ttl is not None else 300,
-                                'ResourceRecords': [
-                                    {
-                                        'Value': value
-                                    }
-                                ]
+                                'ResourceRecords': resource_records
                             }
                         }
                     ]
@@ -162,28 +166,110 @@ class Provider(BaseProvider):
             )
             return True
         except botocore.exceptions.ClientError as error:
-            LOGGER.debug(str(error), exc_info=True)
+            if "Duplicate Resource Record" in error.response['Error']['Message']:
+                # Duplicate resource, that have been a noop. This is expected.
+                return True
+            LOGGER.error(str(error), exc_info=True)
+            return False
 
     def _create_record(self, rtype, name, content):
         """Create a record in the hosted zone."""
+        existing_records = self._list_record_sets(rtype, name)
+        if existing_records:
+            existing_record = existing_records[0]
+            if isinstance(existing_records[0]['content'], list):
+                return self._change_record_sets(
+                    'UPSERT', existing_record['type'], existing_record['name'],
+                    existing_record['content'] + [content])
+            return self._change_record_sets(
+                'UPSERT', rtype, name, [existing_record['content']] + [content])
         return self._change_record_sets('CREATE', rtype, name, content)
 
     def _update_record(self, identifier=None, rtype=None, name=None, content=None):
         """Update a record from the hosted zone."""
-        return self._change_record_sets('UPSERT', rtype, name, content)
+        if identifier:
+            records = [record for record in self._list_records()
+                       if identifier == _identifier(record)]
+            if not records:
+                raise ValueError('No record found for identifier {0}'.format(identifier))
+            record = records[0]
+            rtype = record['type']
+            name = record['name']
+
+        existing_records = self._list_record_sets(rtype, name)
+        if not existing_records:
+            raise ValueError('No matching record to update was found.')
+
+        for existing_record in existing_records:
+            if isinstance(existing_record['content'], list):
+                # Multiple values in record.
+                LOGGER.warning(
+                    'Warning, multiple records found for given parameters, '
+                    'only first entry will be updated: %s', existing_record)
+                new_content = existing_record['content'].copy()
+                new_content[0] = content
+            else:
+                new_content = content
+
+            self._change_record_sets('UPSERT', existing_record['type'],
+                                     existing_record['name'], new_content)
+
+        return True
 
     def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         """Delete a record from the hosted zone."""
-        return self._change_record_sets('DELETE', rtype, name, content)
+        if identifier:
+            matching_records = [record for record in self._list_records()
+                                if identifier == _identifier(record)]
+            if not matching_records:
+                raise ValueError('No record found for identifier {0}'.format(identifier))
+            rtype = matching_records[0]['type']
+            name = matching_records[0]['name']
+            content = matching_records[0]['content']
 
-    def _format_content(self, rtype, content):  # pylint: disable=no-self-use
-        return content[1:-1] if rtype in ['TXT', 'SPF'] else content
+        existing_records = self._list_record_sets(rtype, name, content)
+        if not existing_records:
+            raise ValueError('No record found for the provided type, name and content')
+
+        for existing_record in existing_records:
+            if isinstance(existing_record['content'], list) and content is not None:
+                # multiple values in record, just remove one value and only if it actually exist
+                if content in existing_record['content']:
+                    existing_record['content'].remove(content)
+                    self._change_record_sets('UPSERT', existing_record['type'],
+                                             existing_record['name'], existing_record['content'])
+            else:
+                # if only one record exist, or if content is not specified, remove whole record
+                self._change_record_sets('DELETE', existing_record['type'],
+                                         existing_record['name'], existing_record['content'])
+
+        return True
 
     def _list_records(self, rtype=None, name=None, content=None):
         """List all records for the hosted zone."""
+        records = self._list_record_sets(rtype, name, content)
+
+        flatten_records = []
+        for record in records:
+            if isinstance(record['content'], list):
+                for one_content in record['content']:
+                    flatten_record = record.copy()
+                    flatten_record['content'] = one_content
+                    flatten_record['id'] = _identifier(flatten_record)
+                    flatten_records.append(flatten_record)
+            else:
+                record['id'] = _identifier(record)
+                flatten_records.append(record)
+
+        LOGGER.debug('list_records: %s', records)
+
+        return flatten_records
+
+    def _list_record_sets(self, rtype=None, name=None, content=None):
         records = []
         paginator = RecordSetPaginator(self.r53_client, self.domain_id)
         for record in paginator.all_record_sets():
+            record_content = []
             if rtype is not None and record['Type'] != rtype:
                 continue
             if name is not None and record['Name'] != self._fqdn_name(name):
@@ -191,10 +277,11 @@ class Provider(BaseProvider):
             if record.get('AliasTarget', None) is not None:
                 record_content = [record['AliasTarget'].get('DNSName', None)]
             if record.get('ResourceRecords', None) is not None:
-                record_content = [self._format_content(record['Type'], value['Value']) for value
+                record_content = [_format_content(record['Type'], value['Value']) for value
                                   in record['ResourceRecords']]
             if content is not None and content not in record_content:
                 continue
+
             LOGGER.debug('record: %s', record)
             records.append({
                 'type': record['Type'],
@@ -202,9 +289,20 @@ class Provider(BaseProvider):
                 'ttl': record.get('TTL', None),
                 'content': record_content[0] if len(record_content) == 1 else record_content,
             })
-        LOGGER.debug('list_records: %s', records)
         return records
 
     def _request(self, action='GET', url='/', data=None, query_params=None):
         # Helper _request is not used in Route53 provider
         pass
+
+
+def _format_content(rtype, content):
+    return content[1:-1] if rtype in ['TXT', 'SPF'] else content
+
+
+def _identifier(record):
+    sha256 = hashlib.sha256()
+    sha256.update(('type=' + record.get('type', '') + ',').encode('utf-8'))
+    sha256.update(('name=' + record.get('name', '') + ',').encode('utf-8'))
+    sha256.update(('data=' + record.get('data', '') + ',').encode('utf-8'))
+    return sha256.hexdigest()[0:7]
