@@ -2,23 +2,22 @@
 from unittest import TestCase
 
 import pytest
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.dnspark import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV1
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class DnsParkProviderTests(TestCase, IntegrationTests):
+# TODO: migrate to IntegrationTestsV2 and its extended test suite
+class DnsParkProviderTests(TestCase, IntegrationTestsV1):
     """TestCase for DNSPark"""
-    Provider = Provider
     provider_name = 'dnspark'
     domain = 'capsulecd.com'
 
     def _filter_headers(self):
         return ['Authorization']
 
-    # TODO: the following skipped suite and fixtures should be enabled
+    # TODO: enable the skipped tests
     @pytest.mark.skip(reason="new test, missing recording")
     def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
@@ -26,8 +25,3 @@ class DnsParkProviderTests(TestCase, IntegrationTests):
     @pytest.mark.skip(reason="new test, missing recording")
     def test_provider_when_calling_list_records_after_setting_ttl(self):
         return
-
-    @pytest.fixture(autouse=True)
-    def _skip_suite(self, request):  # pylint: disable=no-self-use
-        if request.node.get_closest_marker('ext_suite_1'):
-            pytest.skip('Skipping extended suite')
